**Example 1: 开通RO组外网**



Input: 

```
tccli cynosdb OpenWan --cli-unfold-argument  \
    --InstanceGrpId cynosdbmysql-grp-o48ssqs5
```

Output: 
```
{
    "Response": {
        "FlowId": 734,
        "RequestId": "ed1bf4b2-4917-4f4f-9f7d-1562e34c9eeb"
    }
}
```

